=========
Changelog
=========

Version 0.1.3
=============

- Enhanced NetCDF stack handling by reading it as a stack
- Keep data set pointer
- Added clipping and limit reading to tile/file boundaries
- Removed 'geometry' as default dimension
- Removed bugs

Version 0.1.2
=============

- Minor changes in styling, package requirements and conda environments

Version 0.1.1
=============

- Minor changes in setup.cfg

Version 0.1.0
=============

- First release
